summaryrefslogtreecommitdiffstats
path: root/lib/libalpm/remove.c
diff options
context:
space:
mode:
authorAllan McRae <allan@archlinux.org>2011-06-28 06:32:09 +0200
committerAllan McRae <allan@archlinux.org>2011-06-28 15:28:23 +0200
commit6d876f9b6be055d54e50d42a34c267aad64c0b21 (patch)
tree8a6e1b413fd61f5ee54440afd20edaa4bcdef386 /lib/libalpm/remove.c
parent9540dfc4d9cc70266a425cc334f78d7805b2340b (diff)
downloadpacman-6d876f9b6be055d54e50d42a34c267aad64c0b21.tar.gz
pacman-6d876f9b6be055d54e50d42a34c267aad64c0b21.tar.xz
Rename pmdepmissing_t to alpm_depmissing_t
Signed-off-by: Allan McRae <allan@archlinux.org>
Diffstat (limited to 'lib/libalpm/remove.c')
-rw-r--r--lib/libalpm/remove.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/lib/libalpm/remove.c b/lib/libalpm/remove.c
index aab49f13..3412774b 100644
--- a/lib/libalpm/remove.c
+++ b/lib/libalpm/remove.c
@@ -77,7 +77,7 @@ static void remove_prepare_cascade(alpm_handle_t *handle, alpm_list_t *lp)
while(lp) {
alpm_list_t *i;
for(i = lp; i; i = i->next) {
- pmdepmissing_t *miss = (pmdepmissing_t *)i->data;
+ alpm_depmissing_t *miss = (alpm_depmissing_t *)i->data;
alpm_pkg_t *info = _alpm_db_get_pkgfromcache(handle->db_local, miss->target);
if(info) {
if(!_alpm_pkg_find(trans->remove, alpm_pkg_get_name(info))) {
@@ -105,7 +105,7 @@ static void remove_prepare_keep_needed(alpm_handle_t *handle, alpm_list_t *lp)
while(lp != NULL) {
alpm_list_t *i;
for(i = lp; i; i = i->next) {
- pmdepmissing_t *miss = (pmdepmissing_t *)i->data;
+ alpm_depmissing_t *miss = (alpm_depmissing_t *)i->data;
void *vpkg;
alpm_pkg_t *pkg = _alpm_pkg_find(trans->remove, miss->causingpkg);
if(pkg == NULL) {
@@ -129,7 +129,7 @@ static void remove_prepare_keep_needed(alpm_handle_t *handle, alpm_list_t *lp)
/** Transaction preparation for remove actions.
* This functions takes a pointer to a alpm_list_t which will be
* filled with a list of pmdepmissing_t* objects representing
* the packages blocking the transaction.
* @param handle the context handle
* @param data a pointer to an alpm_list_t* to fill
@@ -129,7 +129,7 @@ static void remove_prepare_keep_needed(alpm_handle_t *handle, alpm_list_t *lp)
/** Transaction preparation for remove actions.
* This functions takes a pointer to a alpm_list_t which will be
- * filled with a list of pmdepmissing_t* objects representing
+ * filled with a list of alpm_depmissing_t* objects representing
* the packages blocking the transaction.
* @param handle the context handle